@@ -5,7 +5,7 @@ use 5.014002;
 use strict;
 use warnings;
 
-use version; our $VERSION = version->declare("v1.1.15");
+use version; our $VERSION = version->declare("v1.1.16");
 
 use Zonemaster::Engine;
 
@@ -136,6 +136,30 @@ sub metadata {
 } ## end sub metadata
 
 Readonly my %TAG_DESCRIPTIONS => (
+    CONSISTENCY01 => sub {
+        __x    # CONSISTENCY:CONSISTENCY01
+          'SOA serial number consistency', @_;
+    },
+    CONSISTENCY02 => sub {
+        __x    # CONSISTENCY:CONSISTENCY02
+          'SOA RNAME consistency', @_;
+    },
+    CONSISTENCY03 => sub {
+        __x    # CONSISTENCY:CONSISTENCY03
+          'SOA timers consistency', @_;
+    },
+    CONSISTENCY04 => sub {
+        __x    # CONSISTENCY:CONSISTENCY04
+          'Name server NS consistency', @_;
+    },
+    CONSISTENCY05 => sub {
+        __x    # CONSISTENCY:CONSISTENCY05
+          'Consistency between glue and authoritative data', @_;
+    },
+    CONSISTENCY06 => sub {
+        __x    # CONSISTENCY:CONSISTENCY06
+          'SOA MNAME consistency', @_;
+    },
     ADDRESSES_MATCH => sub {
         __x    # CONSISTENCY:ADDRESSES_MATCH
           'Glue records are consistent between glue and authoritative data.', @_;
@@ -245,7 +269,7 @@ Readonly my %TAG_DESCRIPTIONS => (
     },
     SOA_TIME_PARAMETER_SET => sub {
         __x    # CONSISTENCY:SOA_TIME_PARAMETER_SET
-          'Saw SOA time parameter set (REFRESH={refresh},RETRY={retry},EXPIRE={expire},'
+          'Saw SOA time parameter set (REFRESH={refresh}, RETRY={retry}, EXPIRE={expire}, '
           . 'MINIMUM={minimum}) on following nameserver set : {ns_list}.', @_;
     },
     TEST_CASE_END => sub {
@@ -256,10 +280,6 @@ Readonly my %TAG_DESCRIPTIONS => (
         __x    # CONSISTENCY:TEST_CASE_START
           'TEST_CASE_START {testcase}.', @_;
     },
-    TOTAL_ADDRESS_MISMATCH => sub {
-        __x    # CONSISTENCY:TOTAL_ADDRESS_MISMATCH
-          'No common nameserver IP addresses between child ({child}) and parent ({glue}).', @_;
-    },
 );
 
 sub tag_descriptions {
@@ -270,6 +290,35 @@ sub version {
     return "$Zonemaster::Engine::Test::Consistency::VERSION";
 }
 
+sub _ip_disabled_message {
+    my ( $results_array, $ns, @rrtypes ) = @_;
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $ns->address->version == $IP_VERSION_6 ) {
+        push @$results_array, map {
+          info(
+            IPV6_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $ns->address->version == $IP_VERSION_4 ) {
+        push @$results_array, map {
+          info(
+            IPV4_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_,
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+    return 0;
+}
+
 ###
 ### Tests
 ###
@@ -287,25 +336,7 @@ sub consistency01 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -383,25 +414,7 @@ sub consistency02 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -466,25 +479,7 @@ sub consistency03 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -560,25 +555,7 @@ sub consistency04 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
@@ -799,25 +776,7 @@ sub consistency06 {
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $local_ns->string,
-                    rrtype => $query_type,
-                }
-              );
+        if ( _ip_disabled_message( \@results, $local_ns, $query_type ) ) {
             next;
         }
 
