@@ -186,10 +186,12 @@ sub metadata {
         ],
         nameserver11 => [
             qw(
-              NO_RESPONSE
-              NO_EDNS_SUPPORT
-              UNKNOWN_OPTION_CODE
-              NS_ERROR
+              N11_NO_EDNS
+              N11_NO_RESPONSE
+              N11_RETURNS_UNKNOWN_OPTION_CODE
+              N11_UNEXPECTED_ANSWER_SECTION
+              N11_UNEXPECTED_RCODE
+              N11_UNSET_AA
               TEST_CASE_END
               TEST_CASE_START
               )
@@ -218,6 +220,62 @@ sub metadata {
 } ## end sub metadata
 
 Readonly my %TAG_DESCRIPTIONS => (
+    NAMESERVER01 => sub {
+        __x    # NAMESERVER:NAMESERVER01
+            'A name server should not be a recursor', @_;
+    },
+    NAMESERVER02 => sub {
+        __x    # NAMESERVER:NAMESERVER02
+            'Test of EDNS0 support', @_;
+    },
+    NAMESERVER03 => sub {
+        __x    # NAMESERVER:NAMESERVER03
+            'Test availability of zone transfer (AXFR)', @_;
+    },
+    NAMESERVER04 => sub {
+        __x    # NAMESERVER:NAMESERVER04
+            'Same source address', @_;
+    },
+    NAMESERVER05 => sub {
+        __x    # NAMESERVER:NAMESERVER05
+            'Behaviour against AAAA query', @_;
+    },
+    NAMESERVER06 => sub {
+        __x    # NAMESERVER:NAMESERVER06
+            'NS can be resolved', @_;
+    },
+    NAMESERVER07 => sub {
+        __x    # NAMESERVER:NAMESERVER07
+            'To check whether authoritative name servers return an upward referral', @_;
+    },
+    NAMESERVER08 => sub {
+        __x    # NAMESERVER:NAMESERVER08
+            'Testing QNAME case insensitivity', @_;
+    },
+    NAMESERVER09 => sub {
+        __x    # NAMESERVER:NAMESERVER09
+            'Testing QNAME case sensitivity', @_;
+    },
+    NAMESERVER10 => sub {
+        __x    # NAMESERVER:NAMESERVER10
+            'Test for undefined EDNS version', @_;
+    },
+    NAMESERVER11 => sub {
+        __x    # NAMESERVER:NAMESERVER11
+            'Test for unknown EDNS OPTION-CODE', @_;
+    },
+    NAMESERVER12 => sub {
+        __x    # NAMESERVER:NAMESERVER12
+            'Test for unknown EDNS flags', @_;
+    },
+    NAMESERVER13 => sub {
+        __x    # NAMESERVER:NAMESERVER13
+            'Test for truncated response on EDNS query', @_;
+    },
+    NAMESERVER14 => sub {
+        __x    # NAMESERVER:NAMESERVER14
+            'Test for unknown version with unknown OPTION-CODE', @_;
+    },
     AAAA_BAD_RDATA => sub {
         __x    # NAMESERVER:AAAA_BAD_RDATA
             'Nameserver {ns} answered AAAA query with an unexpected RDATA length ({length} instead of 16).', @_;
@@ -351,17 +409,41 @@ Readonly my %TAG_DESCRIPTIONS => (
         __x    # NAMESERVER:NS_ERROR
           'Erroneous response from nameserver {ns}.', @_;
     },
+    N10_EDNS_RESPONSE_ERROR => sub {
+        __x    # NAMESERVER:N10_EDNS_RESPONSE_ERROR
+          'Expected RCODE but received erroneous response to an EDNS version 1 query. Fetched from the nameservers with IP addresses {ns_ip_list}', @_;
+    },
     N10_NO_RESPONSE_EDNS1_QUERY => sub {
-        __x    # N10_NO_RESPONSE_EDNS1_QUERY
+        __x    # NAMESERVER:N10_NO_RESPONSE_EDNS1_QUERY
           'No response to an EDNS version 1 query. Fetched from the nameservers with IP addresses {ns_ip_list}', @_;
     },
     N10_UNEXPECTED_RCODE => sub {
-        __x    # N10_UNEXPECTED_RCODE
+        __x    # NAMESERVER:N10_UNEXPECTED_RCODE
           'Erroneous RCODE ("{rcode}") in response to an EDNS version 1 query. Fetched from the nameservers with IP addresses {ns_ip_list}', @_;
     },
-    N10_EDNS_RESPONSE_ERROR => sub {
-        __x    # N10_EDNS_RESPONSE_ERROR
-          'Expected RCODE but received erroneous response to an EDNS version 1 query. Fetched from the nameservers with IP addresses {ns_ip_list}', @_;
+    N11_NO_EDNS => sub {
+        __x    # NAMESERVER:N11_N11_NO_EDNS
+          'The DNS response, on query with unknown EDNS option-code, does not contain any EDNS from name servers "{ns_ip_list}".', @_;
+    },
+    N11_NO_RESPONSE => sub {
+        __x    # NAMESERVER:N11_NO_RESPONSE
+          'There is no response on query with unknown EDNS option-code from name servers "{ns_ip_list}".', @_;
+    },
+    N11_RETURNS_UNKNOWN_OPTION_CODE => sub {
+        __x    # NAMESERVER:N11_RETURNS_UNKNOWN_OPTION_CODE
+          'The DNS response contains an unknown EDNS option-code. Returned from name servers "{ns_ip_list}".', @_;
+    },
+    N11_UNEXPECTED_ANSWER_SECTION => sub {
+        __x    # NAMESERVER:N11_UNEXPECTED_ANSWER_SECTION
+          'The DNS response, on query with unknown EDNS option-code, does not contain the expected SOA record in the answer section from name servers "{ns_ip_list}".', @_;
+    },
+    N11_UNEXPECTED_RCODE => sub {
+        __x    # NAMESERVER:N11_UNEXPECTED_RCODE
+          'The DNS response, on query with unknown EDNS option-code, has unexpected RCODE name "{rcode}" from name servers "{ns_ip_list}".', @_;
+    },
+    N11_UNSET_AA => sub {
+        __x    # NAMESERVER:N11_UNSET_AA
+          'The DNS response, on query with unknown EDNS option-code, is unexpectedly not authoritative from name servers "{ns_ip_list}".', @_;
     },
     QNAME_CASE_INSENSITIVE => sub {
         __x    # NAMESERVER:QNAME_CASE_INSENSITIVE
@@ -409,27 +491,45 @@ sub version {
     return "$Zonemaster::Engine::Test::Nameserver::VERSION";
 }
 
+sub _ip_disabled_message {
+    my ( $results_array, $ns, @rrtypes ) = @_;
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $ns->address->version == $IP_VERSION_6 ) {
+        push @$results_array, map {
+          info(
+            IPV6_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+
+    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $ns->address->version == $IP_VERSION_4 ) {
+        push @$results_array, map {
+          info(
+            IPV4_DISABLED => {
+                ns     => $ns->string,
+                rrtype => $_,
+            }
+          )
+        } @rrtypes;
+        return 1;
+    }
+    return 0;
+}
+
 sub nameserver01 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
 
-    my @nss;
-    {
-        my %nss = map { $_->string => $_ }
-          @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-          @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
-        @nss = values %nss;
-    }
-
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_6 } @nss;
-    }
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_4 } @nss;
-    }
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
     for my $ns ( @nss ) {
 
+        next if ( _ip_disabled_message( \@results, $ns, q{A} ) );
+
         my $response_count = 0;
         my $nxdomain_count = 0;
         my $is_no_recursor = 1;
@@ -477,13 +577,12 @@ sub nameserver02 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
     my %nsnames_and_ip;
+    my $n_error = 0;
 
-    foreach
-      my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) }, @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-    {
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+    foreach my $local_ns ( @nss ) {
+        next if ( _ip_disabled_message( \@results, $local_ns, q{SOA} ) );
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -491,6 +590,7 @@ sub nameserver02 {
         if ( $p ) {
             if ( $p->rcode eq q{FORMERR} and not $p->has_edns) {
                 push @results, info( NO_EDNS_SUPPORT => { ns => $local_ns->string } );
+                $n_error++;
             }
             elsif ( $p->rcode eq q{NOERROR} and not $p->edns_rcode and $p->get_records( q{SOA}, q{answer} ) and $p->edns_version == 0 ) {
                 $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short }++;
@@ -504,6 +604,7 @@ sub nameserver02 {
                         domain => $zone->name,
                     }
                   );
+                $n_error++;
             }
             elsif ( $p->rcode eq q{NOERROR} and $p->has_edns and $p->edns_version != 0 ) {
                 push @results,
@@ -513,9 +614,11 @@ sub nameserver02 {
                         domain => $zone->name,
                     }
                   );
+                $n_error++;
             }
             else {
                 push @results, info( NS_ERROR => { ns => $local_ns->string } );
+                $n_error++;
             }
         }
         else {
@@ -528,6 +631,7 @@ sub nameserver02 {
                         domain => $zone->name,
                     }
                   );
+                $n_error++;
             }
             else {
                 push @results,
@@ -537,13 +641,14 @@ sub nameserver02 {
                         domain => $zone->name,
                     }
                   );
+                $n_error++;
             }
         }
 
         $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short }++;
     } ## end foreach my $local_ns ( @{ Zonemaster::Engine::TestMethods...})
 
-    if ( scalar keys %nsnames_and_ip and not grep { $_->tag ne q{TEST_CASE_START} } @results ) {
+    if ( scalar keys %nsnames_and_ip and not $n_error ) {
         push @results,
           info(
             EDNS0_SUPPORT => {
@@ -560,13 +665,11 @@ sub nameserver03 {
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
     my %nsnames_and_ip;
 
-    foreach
-      my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) }, @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-    {
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
+    foreach my $local_ns ( @nss ) {
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+        next if ( _ip_disabled_message( \@results, $local_ns, q{AXFR} ) );
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -592,14 +695,13 @@ sub nameserver04 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
     my %nsnames_and_ip;
+    my $n_error = 0;
 
-    foreach
-      my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) }, @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-    {
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
+    foreach my $local_ns ( @nss ) {
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+        next if ( _ip_disabled_message( \@results, $local_ns, q{SOA} ) );
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -613,12 +715,13 @@ sub nameserver04 {
                         source => $p->answerfrom,
                     }
                   );
+                $n_error++;
             }
         }
         $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short }++;
     } ## end foreach my $local_ns ( @{ Zonemaster::Engine::TestMethods...})
 
-    if ( scalar keys %nsnames_and_ip and not grep { $_->tag ne q{TEST_CASE_START} } @results ) {
+    if ( scalar keys %nsnames_and_ip and not $n_error) {
         push @results,
           info(
             SAME_SOURCE_IP => {
@@ -637,32 +740,14 @@ sub nameserver05 {
     my $aaaa_issue = 0;
     my @aaaa_ok;
 
-    foreach my $ns ( @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) } ) {
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
+
+    foreach my $ns ( @nss ) {
+
+        next if ( _ip_disabled_message( \@results, $ns, q{A} ) );
 
         next if $nsnames_and_ip{ $ns->name->string . q{/} . $ns->address->short };
 
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $ns->address->version == $IP_VERSION_6 ) {
-            push @results,
-              info(
-                IPV6_DISABLED => {
-                    ns     => $ns->string,
-                    rrtype => q{A},
-                }
-              );
-            next;
-        }
-
-        if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $ns->address->version == $IP_VERSION_4 ) {
-            push @results,
-              info(
-                IPV4_DISABLED => {
-                    ns     => $ns->string,
-                    rrtype => q{A},
-                }
-              );
-            next;
-        }
-
         $nsnames_and_ip{ $ns->name->string . q{/} . $ns->address->short }++;
 
         my $p = $ns->query( $zone->name, q{A}, { usevc => 0 } );
@@ -716,7 +801,7 @@ sub nameserver05 {
                         $aaaa_issue++;
                     }
                     else {
-                        push @aaaa_ok, $rr->address;    
+                        push @aaaa_ok, $rr->address;
                     }
                 }
             }
@@ -740,8 +825,7 @@ sub nameserver06 {
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
     my @all_nsnames = uniq map { lc( $_->string ) } @{ Zonemaster::Engine::TestMethods->method2( $zone ) },
       @{ Zonemaster::Engine::TestMethods->method3( $zone ) };
-    my @all_nsnames_with_ip = uniq map { lc( $_->name->string ) } @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-      @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
+    my @all_nsnames_with_ip = uniq map { lc( $_->name->string ) } @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
     my @all_nsnames_without_ip;
     my %diff;
 
@@ -777,17 +861,15 @@ sub nameserver07 {
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
     my %nsnames_and_ip;
     my %nsnames;
+    my $n_error = 0;
 
     if ( $zone->name eq q{.} ) {
         push @results, info( UPWARD_REFERRAL_IRRELEVANT => {} );
     }
     else {
-        foreach my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-            @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-        {
-            next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
-
-            next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+        my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
+        foreach my $local_ns ( @nss ) {
+            next if ( _ip_disabled_message( \@results, $local_ns, q{NS} ) );
 
             next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -797,13 +879,14 @@ sub nameserver07 {
 
                 if ( @ns ) {
                     push @results, info( UPWARD_REFERRAL => { ns => $local_ns->string } );
+                    $n_error++;
                 }
             }
             $nsnames{ $local_ns->name }++;
             $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short }++;
         } ## end foreach my $local_ns ( @{ Zonemaster::Engine::TestMethods...})
 
-        if ( scalar keys %nsnames_and_ip and not grep { $_->tag ne q{TEST_CASE_START} } @results ) {
+        if ( scalar keys %nsnames_and_ip and not $n_error ) {
             push @results,
               info(
                 NO_UPWARD_REFERRAL => {
@@ -829,12 +912,11 @@ sub nameserver08 {
         $randomized_uc_name = scramble_case $original_name;
     } while ( $randomized_uc_name eq $original_name );
 
-    foreach
-      my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) }, @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-    {
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+    foreach my $local_ns ( @nss ) {
+
+        next if ( _ip_disabled_message( \@results, $local_ns, q{SOA} ) );
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -888,12 +970,11 @@ sub nameserver09 {
         $randomized_uc_name2 = scramble_case $original_name;
     } while ( $randomized_uc_name2 eq $original_name or $randomized_uc_name2 eq $randomized_uc_name1 );
 
-    foreach
-      my $local_ns ( @{ Zonemaster::Engine::TestMethods->method4( $zone ) }, @{ Zonemaster::Engine::TestMethods->method5( $zone ) } )
-    {
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) and $local_ns->address->version == $IP_VERSION_6 );
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
-        next if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) and $local_ns->address->version == $IP_VERSION_4 );
+    foreach my $local_ns ( @nss ) {
+
+        next if ( _ip_disabled_message( \@results, $local_ns, $record_type ) );
 
         next if $nsnames_and_ip{ $local_ns->name->string . q{/} . $local_ns->address->short };
 
@@ -1014,27 +1095,18 @@ sub nameserver10 {
     my %unexpected_rcode;
     my @edns_response_error;
 
-    my @nss;
-    {
-        my %nss = map { $_->string => $_ }
-          @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-          @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
-        @nss = values %nss;
-    }
-
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_6 } @nss;
-    }
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_4 } @nss;
-    }
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
     for my $ns ( @nss ) {
-        my $p = $ns->query( $zone->name, q{SOA}, { edns_details => { version => 0 } } );
-        
+
+        next if ( _ip_disabled_message( \@results, $ns, q{SOA} ) );
+
+        #To be changed to '$ns->query( $zone->name, q{SOA}, { edns_details => { version => 0 } } );' when PR#1147 is merged.
+        my $p = $ns->query( $zone->name, q{SOA}, { edns_details => { udp_size => 512 } } );
+
         if ( $p and $p->rcode eq q{NOERROR} ){
             my $p2 = $ns->query( $zone->name, q{SOA}, { edns_details => { version => 1 } } );
-            
+
             if ( $p2 ) {
                 if ( ($p2->rcode ne q{NOERROR} and $p2->edns_rcode != 1) ) {
                     push @{ $unexpected_rcode{$p->rcode} }, $ns->address->short;
@@ -1088,20 +1160,12 @@ sub nameserver11 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
 
-    my @nss;
-    {
-        my %nss = map { $_->string => $_ }
-          @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-          @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
-        @nss = values %nss;
-    }
-
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_6 } @nss;
-    }
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_4 } @nss;
-    }
+    my @no_response;
+    my %unexpected_rcode;
+    my @no_edns;
+    my @unexpected_answer;
+    my @unset_aa;
+    my @unknown_opt_code;
 
     # Choose an unassigned EDNS0 Option Codes
     # values 15-26945 are Unassigned. Let's say we use 137 ???
@@ -1110,32 +1174,75 @@ sub nameserver11 {
     my $opt_length = length($opt_data);
     my $rdata = $opt_code*65536 + $opt_length;
 
-    for my $ns ( @nss ) {
-        my $p = $ns->query( $zone->name, q{SOA}, { edns_details => { data => $rdata } } );
-        if ( $p ) {
-            if ( $p->rcode eq q{FORMERR} and not $p->edns_rcode ) {
-                push @results, info( NO_EDNS_SUPPORT => { ns => $ns->string } );
-            }
-            elsif ( defined $p->edns_data ) {
-                push @results, info( UNKNOWN_OPTION_CODE => { ns => $ns->string } );
-            }
-            elsif ( $p->rcode eq q{NOERROR} and not $p->edns_rcode and $p->edns_version == 0 and not defined $p->edns_data and $p->get_records( q{SOA}, q{answer} ) ) {
-                next;
-            }
-            else {
-                push @results, info( NS_ERROR => { ns => $ns->string, } );
-            }
-        }
-        else {
-            push @results,
-              info(
-                NO_RESPONSE => {
-                    ns     => $ns->string,
-                    domain => $zone->name,
-                }
-              );
-        }
+    foreach my $ns ( @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) } ) {
 
+        next if ( _ip_disabled_message( \@results, $ns, q{SOA} ) );
+
+        #To be changed to '$ns->query( $zone->name, q{SOA}, { edns_details => { version => 0 } } );' when PR#1147 is merged.
+        my $p = $ns->query( $zone->name, q{SOA}, { edns_details => { udp_size => 512 } } );
+
+        if ( not $p or not $p->has_edns or $p->rcode ne q{NOERROR} or not $p->aa or not $p->get_records_for_name(q{SOA}, $zone->name, q{answer}) ){
+            next;
+        }
+        
+        #To be changed to '$ns->query( $zone->name, q{SOA}, { edns_details => { data => $rdata } } );' when PR#1147 is merged.
+        $p = $ns->query( $zone->name, q{SOA}, { edns_details => { data => $rdata, udp_size => 512 } } );
+
+        if ( $p ) {
+            if ( $p->rcode ne q{NOERROR} ){
+                push @{ $unexpected_rcode{$p->rcode} }, $ns->address->short;
+            }
+            
+            elsif ( not $p->has_edns ){
+                push @no_edns, $ns->address->short;
+            }
+            
+            elsif ( not $p->get_records_for_name(q{SOA}, $zone->name, q{answer}) ){
+                push @unexpected_answer, $ns->address->short;
+            }
+            
+            elsif ( not $p->aa ){
+                push @unset_aa, $ns->address->short;
+            }
+            
+            elsif ( defined $p->edns_data ) {
+                push @unknown_opt_code, $ns->address->short;
+            }
+        }
+        else{
+            push @no_response, $ns->address->short;
+        }
+    }
+
+    if ( scalar @no_response ){
+        push @results, info( N11_NO_RESPONSE => { ns_ip_list => join( q{;}, uniq sort @no_response ) } );
+    }
+
+    if ( scalar keys %unexpected_rcode ){
+        push @results, map {
+          info(
+            N11_UNEXPECTED_RCODE => {
+                rcode     => $_,
+                ns_ip_list => join( q{;}, uniq sort @{ $unexpected_rcode{$_} } )
+            }
+          )
+        } keys %unexpected_rcode;
+    }
+
+    if ( scalar @no_edns ){
+        push @results, info( N11_NO_EDNS => { ns_ip_list => join( q{;}, uniq sort @no_edns ) } );
+    }
+
+    if ( scalar @unexpected_answer ){
+        push @results, info( N11_UNEXPECTED_ANSWER_SECTION => { ns_ip_list => join( q{;}, uniq sort @unexpected_answer ) } );
+    }
+
+    if ( scalar @unset_aa ){
+        push @results, info( N11_UNSET_AA => { ns_ip_list => join( q{;}, uniq sort @unset_aa ) } );
+    }
+
+    if ( scalar @unknown_opt_code ){
+        push @results, info( N11_RETURNS_UNKNOWN_OPTION_CODE => { ns_ip_list => join( q{;}, uniq sort @unknown_opt_code ) } );
     }
 
     return ( @results, info( TEST_CASE_END => { testcase => (split /::/, (caller(0))[3])[-1] } ) );
@@ -1145,22 +1252,12 @@ sub nameserver12 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
 
-    my @nss;
-    {
-        my %nss = map { $_->string => $_ }
-          @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-          @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
-        @nss = values %nss;
-    }
-
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_6 } @nss;
-    }
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_4 } @nss;
-    }
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
     for my $ns ( @nss ) {
+
+        next if ( _ip_disabled_message( \@results, $ns, q{SOA} ) );
+
         my $p = $ns->query( $zone->name, q{SOA}, { edns_details => { z => 3 } } );
         if ( $p ) {
             if ( $p->rcode eq q{FORMERR} and not $p->edns_rcode ) {
@@ -1194,23 +1291,13 @@ sub nameserver13 {
     my ( $class, $zone ) = @_;
     push my @results, info( TEST_CASE_START => { testcase => (split /::/, (caller(0))[3])[-1] } );
 
-    my @nss;
-    {
-        my %nss = map { $_->string => $_ }
-          @{ Zonemaster::Engine::TestMethods->method4( $zone ) },
-          @{ Zonemaster::Engine::TestMethods->method5( $zone ) };
-        @nss = values %nss;
-    }
-
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv6}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_6 } @nss;
-    }
-    if ( not Zonemaster::Engine::Profile->effective->get(q{net.ipv4}) ) {
-        @nss = grep { $_->address->version != $IP_VERSION_4 } @nss;
-    }
+    my @nss =  @{ Zonemaster::Engine::TestMethods->method4and5( $zone ) };
 
     for my $ns ( @nss ) {
-        my $p = $ns->query( $zone->name, q{SOA}, { usevc => 0, fallback => 0, edns_details => { do => 1, udp_size => 512  } } );
+
+        next if ( _ip_disabled_message( \@results, $ns, q{SOA} ) );
+
+        my $p = $ns->query( $zone->name, q{SOA}, { usevc => 0, fallback => 0, edns_details => { do => 1, udp_size => 512 } } );
         if ( $p ) {
             if ( $p->rcode eq q{FORMERR} and not $p->edns_rcode ) {
                 push @results, info( NO_EDNS_SUPPORT => { ns => $ns->string, } );
