@@ -7,18 +7,32 @@ use warnings;
 
 use version; our $VERSION = version->declare("v1.1.13");
 
-use parent 'Exporter';
+use Exporter 'import';
+BEGIN {
+    our @EXPORT_OK = qw[
+      info
+      ipversion_ok
+      name
+      ns
+      parse_hints
+      pod_extract_for
+      should_run_test
+      scramble_case
+      test_levels
+    ];
+    our %EXPORT_TAGS = ( all => \@EXPORT_OK );
 
-use Zonemaster::Engine;
-use Zonemaster::Engine::Profile;
-use Zonemaster::Engine::DNSName;
-use Zonemaster::Engine::Constants qw[:ip];
+    ## no critic (Modules::ProhibitAutomaticExportation)
+    our @EXPORT = qw[ ns info name pod_extract_for scramble_case ];
+}
+
+use Net::DNS::ZoneFile;
 use Pod::Simple::SimpleTree;
 
-## no critic (Modules::ProhibitAutomaticExportation)
-our @EXPORT      = qw[ ns info name pod_extract_for scramble_case ];
-our @EXPORT_OK   = qw[ ns info name pod_extract_for test_levels should_run_test scramble_case ipversion_ok ];
-our %EXPORT_TAGS = ( all => \@EXPORT_OK );
+use Zonemaster::Engine;
+use Zonemaster::Engine::Constants qw[:ip];
+use Zonemaster::Engine::DNSName;
+use Zonemaster::Engine::Profile;
 
 ## no critic (Subroutines::RequireArgUnpacking)
 sub ns {
@@ -153,6 +167,75 @@ sub scramble_case {
     return $newstring;
 }    # end sub scramble_case
 
+sub parse_hints {
+    my $string = shift;
+
+    # Reject anything that is forbidden in hints files but allowed in zone files
+    # in general.
+    if ( $string =~ /^\$(TTL|INCLUDE|ORIGIN|GENERATE)/m ) {
+        die "Forbidden directive \$$1\n";
+    }
+
+    my $rrs = Net::DNS::ZoneFile->parse( \$string );
+    if ( !defined $rrs ) {
+        die "Unable to parse root hints\n";
+    }
+
+    my %ns;
+    my %glue;
+    for my $rr ( @$rrs ) {
+        if ( $rr->class ne 'IN' ) {
+            my $rrclass = $rr->class;
+            die "Forbidden RR class $rrclass\n";
+        }
+
+        if ( $rr->type eq 'NS' ) {
+            if ( $rr->owner ne '.' ) {
+                my $owner = $rr->owner;
+                die "Owner name for NS record must be \".\"\n";
+            }
+            $ns{ $rr->nsdname } = 0;
+        }
+        elsif ( $rr->type eq 'A' || $rr->type eq 'AAAA' ) {
+            $glue{ $rr->owner } = $rr->type;
+        }
+        else {
+            my $rrtype = $rr->type;
+            die "Forbidden RR type $rrtype\n";
+        }
+    } ## end for my $rr ( @$rrs )
+
+    for my $owner ( sort keys %glue ) {
+        if ( exists $ns{$owner} ) {
+            $ns{$owner} = 1;
+        }
+        else {
+            my $rrtype = $glue{$owner};
+            die "Ownername of $rrtype record does not match any NS RDATA\n";
+        }
+    }
+
+    for my $nsdname ( sort keys %ns ) {
+        if ( $ns{$nsdname} == 0 ) {
+            die "No address record found for NS $nsdname\n";
+        }
+    }
+
+    if ( !%ns ) {
+        die "No NS record found\n";
+    }
+
+    # Extract hint data
+    my %hints;
+    for my $rr ( @{ $rrs } ) {
+        if ( $rr->type eq 'A' or $rr->type eq 'AAAA' ) {
+            push @{ $hints{$rr->owner} }, $rr->address;
+        }
+    }
+
+    return \%hints;
+}
+
 1;
 
 =head1 NAME
@@ -179,14 +262,58 @@ is also added to the global logger object's list of entries.
 
 Creates and returns a nameserver object with the given name and address.
 
-=item policy()
-
-Returns a reference to the global policy hash.
-
 =item name($string_name_or_zone)
 
 Creates and returns a L<Zonemaster::Engine::DNSName> object for the given argument.
 
+=item parse_hints($string)
+
+Parses a string in the root hints format into the format expected by
+Zonemaster::Engine::Resolver->add_fake_addresses().
+
+Returns a hashref with domain names as keys and arrayrefs to IP addresses as
+values.
+
+Throws an exception if the inputs is not valid root hints text.
+
+A root hints file is a valid RFC 1035 zone file of the same type IANA publishes
+to be used as hint file for name servers
+L<https://www.internic.net/domain/named.root>.
+
+In addition to being valid zone file the following restrictions are imposed on
+the root hints format:
+
+=over
+
+=item *
+The file must not contain any $TTL, $ORIGIN, $INCLUDE or $GENERATE directives.
+
+=item *
+The class field of all records must be "IN" or absent. If class is absent, IN is
+assumed.
+
+=item *
+The TTL field may be absent or present. The TTL value is ignored.
+
+=item *
+The RR type of all DNS records must be NS, A or AAAA.
+
+=item *
+The file must contain at least one NS record.
+
+=item *
+The owner name of all NS records must be C<.>.
+
+=item *
+For every NS record there must be at least one address record (A or AAAA) whose
+owner name is identical to the domain name in the RDATA of the NS record.
+
+=item *
+All address records (A or AAAA) must have an owner name that is identical to the
+domain name in the RDATA of some NS record in the zone.
+
+=back
+
 =item pod_extract_for($testname)
 
 Will attempt to extract the POD documentation for the test methods in
